@@ -17,8 +17,9 @@ SUPPORTED_REF_GENOME = \
                   ["Zebrafish", "danRer7", "UCSC"],
                   ["Zebrafish", "danRer10", "UCSC"],
                   ["Zebrafish", "danRer11", "UCSC"],
-                  ["Xenopus", "xenTro2", "UCSC"],
-                  ["Xenopus", "xenTro3", "UCSC"],
+                  ["Xenopus tropicalis", "xenTro2", "UCSC"],
+                  ["Xenopus tropicalis", "xenTro3", "UCSC"],
+                  ["Xenopus laevis", "Xenopus_laevis_v10.1", "NCBI"],
                   ["Rat", "rn4", "UCSC"],
                   ["Rat", "rn5", "UCSC"],
                   ["Rat", "rn6", "UCSC"],
